@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/ed.decls.h,v 3.25 1997/10/27 22:44:20 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/ed.decls.h,v 3.28 1998/09/04 21:16:38 christos Exp $ */
 /*
  * ed.decls.h: Editor external definitions
  */
@@ -234,6 +234,10 @@ extern  CCRETVAL        e_complete_all		__P((int));
 extern  CCRETVAL        e_complete_fwd		__P((int));
 extern  CCRETVAL        e_complete_back		__P((int));
 extern  CCRETVAL        e_dabbrev_expand	__P((int));
+extern  CCRETVAL	e_copy_to_clipboard	__P((int));
+extern  CCRETVAL	e_paste_from_clipboard	__P((int));
+extern  CCRETVAL	e_dosify_next		__P((int));
+extern  CCRETVAL	e_dosify_prev		__P((int));
 
 /*
  * ed.inputl.c
@@ -264,7 +268,7 @@ extern	void	 ResetXmap		__P((void));
 extern	int	 DeleteXkey		__P((CStr *));
 extern	void	 PrintXkey		__P((CStr *));
 extern	int	 printOne		__P((CStr *, XmapVal *, int));
-extern	int		  parseescape	__P((Char **));
+extern	int		  parseescape	__P((const Char **));
 extern	unsigned char    *unparsestring	__P((CStr *, unsigned char *, Char *));
 
 #endif /* _h_ed_decls */
