@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/ed.defns.c,v 3.29 1998/04/08 13:58:31 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/ed.defns.c,v 3.32 1998/09/09 10:29:18 christos Exp $ */
 /*
  * ed.defns.c: Editor function definitions and initialization
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: ed.defns.c,v 3.29 1998/04/08 13:58:31 christos Exp $")
+RCSID("$Id: ed.defns.c,v 3.32 1998/09/09 10:29:18 christos Exp $")
 
 #include "ed.h"
 
@@ -269,8 +269,17 @@ PFCmd   CcFuncTbl[] = {		/* table of available commands */
 #define		F_COMMAND_NORM	111
     e_dabbrev_expand,
 #define		F_DABBREV_EXPAND	112
+	e_copy_to_clipboard,
+#define		F_COPY_CLIP		113
+	e_paste_from_clipboard,
+#define		F_PASTE_CLIP	114
+	e_dosify_next,
+#define		F_DOSIFY_NEXT	115
+	e_dosify_prev,
+#define		F_DOSIFY_PREV	116
     0				/* DUMMY VALUE */
-#define		F_NUM_FNS	113
+#define		F_NUM_FNS	117
+
 };
 
 KEYCMD  NumFuns = F_NUM_FNS;
@@ -1830,6 +1839,23 @@ editinit()
     f->func = F_YANK_KILL;
     f->desc = CSAVS(3, 114, "Paste cut buffer at cursor position");
 
+    f++;
+    f->name = "e_copy_to_clipboard";
+    f->func = F_COPY_CLIP;
+    f->desc = CSAVS(3, 115, "(win32 only)Copy cut buffer to system clipboard");
+    f++;
+    f->name = "e_paste_from_clipboard";
+    f->func = F_PASTE_CLIP;
+    f->desc = CSAVS(3, 116, "(win32 only)Paste clipboard buffer at cursor position");
+    f++;
+    f->name = "e_dosify_next";
+    f->func = F_DOSIFY_NEXT;
+    f->desc = CSAVS(3, 117, "(win32 only)Convert each '/' in next word to '\\\\'");
+    f++;
+    f->name = "e_dosify_prev";
+    f->func = F_DOSIFY_PREV;
+    f->desc = CSAVS(3, 118, "(win32 only)Convert each '/' in previous word to '\\\\'");
+
     f++;
     f->name = NULL;
     f->func = 0;
