@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.misc.c,v 3.22 1996/04/26 19:20:01 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.misc.c,v 3.23 1997/02/23 19:03:23 christos Exp $ */
 /*
  * sh.misc.c: Miscelaneous functions
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.misc.c,v 3.22 1996/04/26 19:20:01 christos Exp $")
+RCSID("$Id: sh.misc.c,v 3.23 1997/02/23 19:03:23 christos Exp $")
 
 static	int	renum	__P((int, int));
 static  Char  **blkend	__P((Char **));
@@ -476,6 +476,21 @@ quote(cp)
     return (cp);
 }
 
+Char   *
+quote_meta(d, s)
+    Char   *d;
+    const Char   *s;
+{
+    Char *r = d;
+    while (*s != '\0') {
+	if (cmap(*s, _META | _DOL | _QF | _QB | _ESC | _GLOB))
+		*d++ = '\\';
+	*d++ = *s++;
+    }
+    *d = '\0';
+    return r;
+}
+
 void
 udvar(name)
     Char   *name;
