@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/sh.types.h,v 3.35 1998/04/08 17:57:31 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/sh.types.h,v 3.36 1998/04/21 16:08:51 christos Exp $ */
 /* sh.types.h: Do the necessary typedefs for each system.
  *             Up till now I avoided making this into a separate file
  *	       But I just wanted to eliminate the whole mess from sh.h
@@ -59,6 +59,15 @@
 # endif /* _PID_T */
 #endif
 
+/***
+ *** MachTen 
+ ***/
+#ifdef __MACHTEN__
+# ifndef _PID_T
+#  define _PID_T
+# endif
+#endif
+
 
 /***
  *** Suns running sunos3.x - sunos4.1.x
