@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tc.sig.h,v 3.18 1996/04/26 19:21:36 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tc.sig.h,v 3.20 1998/04/08 17:57:37 christos Exp $ */
 /*
  * tc.sig.h: Signal handling
  *
@@ -38,7 +38,7 @@
 #ifndef _h_tc_sig
 #define _h_tc_sig
 
-#if (SYSVREL > 0) || defined(BSD4_4) || defined(_MINIX)
+#if (SYSVREL > 0) || defined(BSD4_4) || defined(_MINIX) || defined(DGUX) || defined(WINNT)
 # include <signal.h>
 # ifndef SIGCHLD
 #  define SIGCHLD SIGCLD
@@ -148,6 +148,9 @@ typedef struct sigvec sigvec_t;
 # define	sigmask(s)	(1 << ((s)-1))
 # ifdef POSIXSIGS
 #  define 	sigpause(a)	(void) bsd_sigpause(a)
+#  ifdef WINNT
+#   undef signal
+#  endif /* WINNT */
 #  define 	signal(a, b)	bsd_signal(a, b)
 # endif /* POSIXSIGS */
 # ifndef _SEQUENT_
