@@ -1,4 +1,4 @@
-/* $Header: /u/christos/cvsroot/tcsh/tw.h,v 3.19 1996/04/26 19:23:05 christos Exp $ */
+/* $Header: /u/christos/cvsroot/tcsh/tw.h,v 3.20 1997/10/02 16:36:35 christos Exp $ */
 /*
  * tw.h: TwENEX functions headers
  */
@@ -78,7 +78,7 @@
 #define ON		1
 #define OFF		0
 #define FILSIZ		512	/* Max reasonable file name length */
-#define ESC		'\033'
+#define ESC             CTL_ESC('\033')
 #define equal(a, b)	(strcmp(a, b) == 0)
 
 #define is_set(var)	adrof(var)
